# Prod 20231106_v0.9.12_base_dl1_dec_931_min-2924_min-1802_6166


Base DL1 prod for missing declination in `20221215_v0.9.12_base_prod`

```
lstmcpipe_generate_config PathConfigAllSkyFull --prod_id 20231106_v0.9.12_base_dl1_dec_931_min-2924_min-1802_6166 --dec_list dec_931 dec_min_2924 dec_min_1802 dec_6166
```

contact: Thomas Vuillaume

